@@ -9,11 +9,6 @@ import matplotlib.pyplot as plt
 import matplotlib.dates as mdates
 import re
 
-def readlast(file):
-    lines = file.readlines()
-    return lines[-1]
-
-
 def is_file_in_time_range(file_path, delta_mins=10, date_selected=datetime.now()):
     """检测文件是否符合期望的时间要求
 
@@ -39,7 +34,8 @@ def is_file_in_time_range(file_path, delta_mins=10, date_selected=datetime.now()
 
         if file_path.endswith("gz"):
             print(f"{file_path} is checking ...")
-            with gzip.open(os.path.join(file_path), mode="rt") as f:
+            # most efficient way to read last line in gzip file
+            with gzip.open(file_path, 'rb') as f:
                 return check_line_in_a_file(f, delta_mins, date_selected)
         else:
             print(f"{file_path} is checking ...")
@@ -66,7 +62,13 @@ def check_line_in_a_file(f, delta_mins, date_selected=datetime.now()):
 
     try:
         first_line = f.readline()
-        last_line = readlast(f)
+        # read list line most efficient from f
+        f.seek(0, SEEK_END)
+        size = f.tell()
+        f.seek(max(size-1024, 0), 0)
+        lines = f.readlines()
+        last_line = lines[-1]
+
 
         if not first_line and not last_line:
             return False
